@@ -1,5 +1,6 @@
 # Copyright (c) 2020 Alexander Todorov <atodorov@MrSenko.com>
 
+from django.conf import settings
 from django.contrib.auth.backends import BaseBackend
 
 
@@ -10,7 +11,8 @@ class AnonymousViewBackend(BaseBackend):
         to enable read-only access which doesn't require login!
     """
     def has_perm(self, user_obj, perm, obj=None):
-        if user_obj.is_anonymous and perm.find('.view_') > -1:
+        if (perm.find('.view_') > -1 and
+                (user_obj.is_anonymous or user_obj.username == settings.ANONYMOUS_USER_NAME)):
             return True
 
         return super().has_perm(user_obj, perm, obj=obj)
