@@ -1,26 +1,29 @@
 # -*- coding: utf-8 -*-
 
 from django.forms import EmailField, ValidationError
+from django.forms.models import model_to_dict
 from modernrpc.core import REQUEST_KEY, rpc_method
 
-from tcms.core.helpers import comments
+from tcms.core import helpers
 from tcms.core.utils import form_errors_to_list
 from tcms.management.models import Component, Tag
 from tcms.rpc import utils
 from tcms.rpc.api.forms.testcase import NewForm, UpdateForm
 from tcms.rpc.decorators import permissions_required
-from tcms.testcases.models import TestCase
+from tcms.testcases.models import TestCase, TestCasePlan
 
 __all__ = (
     'create',
     'update',
     'filter',
+    'sortkeys',
     'remove',
 
     'add_comment',
     'remove_comment',
 
     'add_component',
+    'comments',
     'remove_component',
 
     'add_notification_cc',
@@ -279,6 +282,33 @@ def filter(query=None):  # pylint: disable=redefined-builtin
     return TestCase.to_xmlrpc(query)
 
 
+@permissions_required('testcases.view_testcase')
+@rpc_method(name='TestCase.sortkeys')
+def sortkeys(query=None):
+    """
+    .. function:: RPC TestCase.sortkeys(query)
+
+        Return information about TestCase position inside TestPlan.
+
+        For example `TestCase.sortkeys({'plan': 3})`
+
+        :param query: Field lookups for :class:`tcms.testcases.models.TestCasePlan`
+        :type query: dict
+        :return: Dictionary of (case_id, sortkey) pairs!
+        :rtype: dict(case_id, sortkey)
+    """
+    if query is None:
+        query = {}
+
+    result = {}
+    for record in TestCasePlan.objects.filter(**query):
+        # NOTE: convert to str() otherwise we get:
+        # Unable to serialize result as valid XML: dictionary key must be string
+        result[str(record.case_id)] = record.sortkey
+
+    return result
+
+
 @permissions_required('testcases.change_testcase')
 @rpc_method(name='TestCase.update')
 def update(case_id, values):
@@ -392,6 +422,8 @@ def add_comment(case_id, comment, **kwargs):
         :type comment: str
         :param kwargs: Dict providing access to the current request, protocol
                 entry point name and handler instance from the rpc method
+        :return: Serialized :class:`django_comments.models.Comment` object
+        :rtype: dict
         :raises PermissionDenied: if missing *django_comments.add_comment* permission
 
         .. important::
@@ -399,7 +431,9 @@ def add_comment(case_id, comment, **kwargs):
             In webUI comments are only shown **only** during test case review!
     """
     case = TestCase.objects.get(pk=case_id)
-    comments.add_comment([case], comment, kwargs.get(REQUEST_KEY).user)
+    created = helpers.comments.add_comment([case], comment, kwargs.get(REQUEST_KEY).user)
+    # we always create only one comment
+    return model_to_dict(created[0])
 
 
 @permissions_required('django_comments.delete_comment')
@@ -417,8 +451,30 @@ def remove_comment(case_id, comment_id=None):
         :raises PermissionDenied: if missing *django_comments.delete_comment* permission
     """
     case = TestCase.objects.get(pk=case_id)
-    to_be_deleted = comments.get_comments(case)
+    to_be_deleted = helpers.comments.get_comments(case)
     if comment_id:
         to_be_deleted = to_be_deleted.filter(pk=comment_id)
 
     to_be_deleted.delete()
+
+
+@permissions_required('django_comments.view_comment')
+@rpc_method(name='TestCase.comments')
+def comments(case_id):
+    """
+    .. function:: TestCase.comments(case_id)
+
+        Return all comment(s) for the specified test case.
+
+        :param case_id: PK of a TestCase object
+        :type case_id: int
+        :return: Serialized list of :class:`django_comments.models.Comment` objects
+        :rtype: list
+        :raises PermissionDenied: if missing *django_comments.view_comment* permission
+    """
+    case = TestCase.objects.get(pk=case_id)
+    result = []
+    for comment in helpers.comments.get_comments(case):
+        result.append(model_to_dict(comment))
+
+    return result
