@@ -2,6 +2,7 @@
 
 from django.conf import settings
 from django.forms.models import model_to_dict
+from django.utils import timezone
 from modernrpc.core import REQUEST_KEY, rpc_method
 
 from tcms.core.contrib.linkreference.models import LinkReference
@@ -48,10 +49,14 @@ def add_comment(execution_id, comment, **kwargs):
         :type comment: str
         :param kwargs: Dict providing access to the current request, protocol
                 entry point name and handler instance from the rpc method
+        :return: Serialized :class:`django_comments.models.Comment` object
+        :rtype: dict
         :raises PermissionDenied: if missing *django_comments.add_comment* permission
     """
     execution = TestExecution.objects.get(pk=execution_id)
-    comments.add_comment([execution], comment, kwargs.get(REQUEST_KEY).user)
+    created = comments.add_comment([execution], comment, kwargs.get(REQUEST_KEY).user)
+    # we always create only one comment
+    return model_to_dict(created[0])
 
 
 @permissions_required('django_comments.delete_comment')
@@ -121,6 +126,14 @@ def update(execution_id, values):
     else:
         raise ValueError(form_errors_to_list(form))
 
+    # if this call updated TE.status then adjust timestamps
+    if values.get('status'):
+        if test_execution.status.weight != 0:
+            test_execution.close_date = timezone.now()
+        else:
+            test_execution.close_date = None
+        test_execution.save()
+
     return test_execution.serialize()
 
 
