@@ -17,12 +17,15 @@ __all__ = (
 
     'add_case',
     'remove_case',
+    'update_case_order',
 
     'add_tag',
     'remove_tag',
 
     'add_attachment',
     'list_attachments',
+
+    'tree',
 )
 
 
@@ -174,13 +177,20 @@ def add_case(plan_id, case_id):
         :type plan_id: int
         :param case_id: PK of TestCase to be added to plan
         :type case_id: int
+        :return: Serialized :class:`tcms.testcases.models.TestCase` object
+                 augmented with a 'sortkey' value
+        :rtype: dict
         :raises TestPlan.DoesNotExit or TestCase.DoesNotExist: if objects specified
                  by PKs are missing
         :raises PermissionDenied: if missing *testcases.add_testcaseplan* permission
     """
     plan = TestPlan.objects.get(pk=plan_id)
     case = TestCase.objects.get(pk=case_id)
-    plan.add_case(case)
+    test_case_plan = plan.add_case(case)
+
+    result = case.serialize()
+    result['sortkey'] = test_case_plan.sortkey
+    return result
 
 
 @permissions_required('testcases.delete_testcaseplan')
@@ -200,6 +210,26 @@ def remove_case(plan_id, case_id):
     TestCasePlan.objects.filter(case=case_id, plan=plan_id).delete()
 
 
+@permissions_required('testcases.change_testcaseplan')
+@rpc_method(name='TestPlan.update_case_order')
+def update_case_order(plan_id, case_id, sortkey):
+    """
+    .. function:: RPC TestPlan.update_case_order(plan_id, case_id, sortkey)
+
+        Update sortkey which controls display order of the given test case in
+        the given test plan.
+
+        :param plan_id: PK of TestPlan holding the selected TestCase
+        :type plan_id: int
+        :param case_id: PK of TestCase to be modified
+        :type case_id: int
+        :param sortkey: Ordering value, e.g. 10, 20, 30
+        :type sortkey: int
+        :raises PermissionDenied: if missing *testcases.delete_testcaseplan* permission
+    """
+    TestCasePlan.objects.filter(case=case_id, plan=plan_id).update(sortkey=sortkey)
+
+
 @permissions_required('attachments.view_attachment')
 @rpc_method(name='TestPlan.list_attachments')
 def list_attachments(plan_id, **kwargs):
@@ -244,3 +274,34 @@ def add_attachment(plan_id, filename, b64content, **kwargs):
         kwargs.get(REQUEST_KEY).user,
         filename,
         b64content)
+
+
+@permissions_required('testplans.view_testplan')
+@rpc_method(name='TestPlan.tree')
+def tree(plan_id):
+    """
+    .. function:: RPC TestPlan.tree(plan_id)
+
+        Returns a list of the ancestry tree for the given TestPlan
+        in a depth-first order!
+
+        :param plan_id: PK of TestPlan to inspect
+        :type plan_id: int
+        :return: A DFS ordered list of all test plans in the family tree
+                 starting from the root of the tree
+        :rtype: list
+        :raises TestPlan.DoesNotExit: if object specified by PK is missing
+    """
+    plan = TestPlan.objects.get(pk=plan_id)
+    result = []
+
+    for record in plan.tree_as_list():
+        result.append({
+            'id': record.pk,
+            'name': record.name,
+            'parent_id': record.parent_id,
+            'tree_depth': record.tree_depth,
+            'url': record.get_full_url(),
+        })
+
+    return result
