@@ -3,9 +3,10 @@ from modernrpc.core import REQUEST_KEY, rpc_method
 
 from tcms.core.utils import form_errors_to_list
 from tcms.management.models import Tag
-from tcms.rpc.api.forms.testrun import NewForm, UpdateForm
+from tcms.rpc.api.forms.testrun import UpdateForm
 from tcms.rpc.decorators import permissions_required
 from tcms.testcases.models import TestCase
+from tcms.testruns.forms import NewRunForm
 from tcms.testruns.models import TestExecution, TestRun
 
 __all__ = (
@@ -39,7 +40,7 @@ def add_case(run_id, case_id):
         :raises DoesNotExist: if objects specified by the PKs don't exist
         :raises PermissionDenied: if missing *testruns.add_testexecution* permission
     """
-    execution = TestRun.objects.get(pk=run_id).add_case_run(
+    execution = TestRun.objects.get(pk=run_id).create_execution(
         case=TestCase.objects.get(pk=case_id)
     )
     return execution.serialize()
@@ -165,23 +166,14 @@ def create(values):
             }
             >>> TestRun.create(values)
     """
-    form = NewForm(values)
-    form.assign_plan(values.get('plan'))
+    form = NewRunForm(values)
+    form.populate(values.get('plan'))
 
     if form.is_valid():
-        test_run = TestRun.objects.create(
-            product_version=form.cleaned_data['plan'].product_version,
-            summary=form.cleaned_data['summary'],
-            notes=form.cleaned_data['notes'],
-            plan=form.cleaned_data['plan'],
-            build=form.cleaned_data['build'],
-            manager=form.cleaned_data['manager'],
-            default_tester=form.cleaned_data['default_tester'],
-        )
-    else:
-        raise ValueError(form_errors_to_list(form))
+        test_run = form.save()
+        return test_run.serialize()
 
-    return test_run.serialize()
+    raise ValueError(form_errors_to_list(form))
 
 
 @permissions_required('testruns.view_testrun')
