@@ -118,6 +118,12 @@ CACHES = {
 STATIC_ROOT = '/Kiwi/static/'
 
 
+AUTHENTICATION_BACKENDS = [
+    'django.contrib.auth.backends.ModelBackend',
+    'guardian.backends.ObjectPermissionBackend',
+]
+
+
 # WARNING: Do not change this unless you know what you are doing !!!
 MIDDLEWARE = [
     'django.contrib.sessions.middleware.SessionMiddleware',
@@ -235,6 +241,7 @@ WSGI_APPLICATION = 'tcms.wsgi.application'
 # this is consumed by kiwitcms-tenants/django-tenants
 TENANT_APPS = [
     'django.contrib.sites',
+    'guardian',
 
     'attachments',
     'django_comments',
@@ -265,6 +272,7 @@ INSTALLED_APPS = TENANT_APPS + [
 
     'colorfield',
     'django_extensions',
+    'tree_queries',
     'vinaigrette',
 
     'tcms.core',
@@ -346,6 +354,7 @@ MODERNRPC_METHODS_MODULES = [
     'tcms.rpc.api.category',
     'tcms.rpc.api.classification',
     'tcms.rpc.api.component',
+    'tcms.rpc.api.markdown',
     'tcms.rpc.api.plantype',
     'tcms.rpc.api.priority',
     'tcms.rpc.api.product',
@@ -368,6 +377,7 @@ if 'tcms.bugs.apps.AppConfig' in INSTALLED_APPS:
 # this list with their own integration classes!
 # https://kiwitcms.readthedocs.io/en/latest/admin.html#configure-external-bug-trackers
 EXTERNAL_BUG_TRACKERS = [
+    'tcms.issuetracker.azure_boards.AzureBoards',
     'tcms.issuetracker.types.Bugzilla',
     'tcms.issuetracker.types.JIRA',
     'tcms.issuetracker.types.GitHub',
