@@ -3,6 +3,7 @@ from django.contrib import admin
 from django.http import HttpResponseRedirect
 from django.urls import reverse
 
+from tcms.core.admin import ObjectPermissionsAdminMixin
 from tcms.core.history import ReadOnlyHistoryAdmin
 from tcms.testplans.models import PlanType, TestPlan
 
@@ -12,7 +13,7 @@ class PlanTypeAdmin(admin.ModelAdmin):
     list_display = ('id', 'name', 'description')
 
 
-class TestPlanAdmin(ReadOnlyHistoryAdmin):
+class TestPlanAdmin(ObjectPermissionsAdminMixin, ReadOnlyHistoryAdmin):
     """
         Does not allow adding new or changing plans.
     """
