@@ -16,44 +16,42 @@ from django.views.generic.base import TemplateView, View
 from django.views.generic.edit import UpdateView
 from django_comments.models import Comment
 
+from guardian.decorators import permission_required as object_permission_required
+
 from tcms.core.contrib.linkreference.models import LinkReference
 from tcms.core.utils import clean_request
-from tcms.management.models import Build, Priority, Tag
-from tcms.testcases.models import BugSystem, TestCasePlan, TestCaseStatus
-from tcms.testcases.views import get_selected_testcases
+from tcms.management.models import Priority, Tag
+from tcms.testcases.models import BugSystem, TestCasePlan, TestCaseStatus, TestCase
 from tcms.testplans.models import TestPlan
 from tcms.testruns.data import TestExecutionDataMixin
-from tcms.testruns.forms import BaseRunForm, NewRunForm, SearchRunForm
+from tcms.testruns.forms import NewRunForm, SearchRunForm
 from tcms.testruns.models import TestExecution, TestExecutionStatus, TestRun
 
 User = get_user_model()  # pylint: disable=invalid-name
 
 
 @method_decorator(permission_required('testruns.add_testrun'), name='dispatch')
-class CreateTestRunView(View):
-    """Display the create test run page."""
+class NewTestRunView(View):
+    """Display new test run page."""
 
     template_name = 'testruns/mutable.html'
-    http_method_names = ['post']
+    http_method_names = ['post', 'get']
 
-    def post(self, request):
-        # If from_plan does not exist will redirect to plans for select a plan
-        plan_id = request.POST.get('from_plan')
+    def get(self, request):
+        plan_id = request.GET.get('p')
         if not plan_id:
             messages.add_message(request,
                                  messages.ERROR,
                                  _('Creating a TestRun requires a TestPlan, select one'))
             return HttpResponseRedirect(reverse('plans-search'))
 
-        if not request.POST.get('case'):
+        if not request.GET.get('c'):
             messages.add_message(request,
                                  messages.ERROR,
                                  _('Creating a TestRun requires at least one TestCase'))
             return HttpResponseRedirect(reverse('test_plan_url_short', args=[plan_id]))
 
-        # Ready to write cases to test plan
-        test_cases = get_selected_testcases(request)
-        test_plan = TestPlan.objects.get(pk=plan_id)
+        test_cases = TestCase.objects.filter(pk__in=request.GET.getlist('c'))
 
         # note: ordered by pk for test_show_create_new_run_page()
         tcs_values = test_cases.select_related('author',
@@ -61,57 +59,60 @@ class CreateTestRunView(View):
                                                'category',
                                                'priority').order_by('pk')
 
-        if request.POST.get('POSTING_TO_CREATE'):
-            form = NewRunForm(request.POST)
-            form.populate(product_id=test_plan.product_id)
-
-            if form.is_valid():
-                # Process the data in form.cleaned_data
-                default_tester = form.cleaned_data['default_tester']
-
-                test_run = TestRun.objects.create(
-                    product_version=test_plan.product_version,
-                    stop_date=None,
-                    summary=form.cleaned_data.get('summary'),
-                    notes=form.cleaned_data.get('notes'),
-                    plan=test_plan,
-                    build=form.cleaned_data['build'],
-                    manager=form.cleaned_data['manager'],
-                    default_tester=default_tester,
-                )
-
-                loop = 1
-                for case in form.cleaned_data['case']:
-                    try:
-                        tcp = TestCasePlan.objects.get(plan=test_plan, case=case)
-                        sortkey = tcp.sortkey
-                    except ObjectDoesNotExist:
-                        sortkey = loop * 10
-
-                    test_run.add_case_run(case=case, sortkey=sortkey,
-                                          assignee=default_tester)
-                    loop += 1
-
-                return HttpResponseRedirect(
-                    reverse('testruns-get', args=[test_run.pk, ])
-                )
-
-        else:
-            form = NewRunForm(initial={
-                'summary': 'Test run for %s' % test_plan.name,
-                'manager': test_plan.author.email,
-                'default_tester': request.user.email,
-                'notes': '',
-            })
-            form.populate(product_id=test_plan.product_id)
+        test_plan = TestPlan.objects.get(pk=plan_id)
+        form = NewRunForm(initial={
+            'summary': 'Test run for %s' % test_plan.name,
+            'manager': test_plan.author.email,
+            'default_tester': request.user.email,
+            'notes': '',
+            'plan': plan_id,
+        })
+        form.populate(plan_id)
 
         context_data = {
-            'test_plan': test_plan,
             'test_cases': tcs_values,
             'form': form,
+            'disabled_cases': get_disabled_test_cases_count(test_cases)
         }
         return render(request, self.template_name, context_data)
 
+    def post(self, request):
+        form = NewRunForm(data=request.POST)
+        form.populate(request.POST.get('plan'))
+
+        if form.is_valid():
+            test_run = form.save()
+            loop = 1
+
+            for case in form.cleaned_data['case']:
+                try:
+                    tcp = TestCasePlan.objects.get(plan=form.cleaned_data['plan'], case=case)
+                    sortkey = tcp.sortkey
+                except ObjectDoesNotExist:
+                    sortkey = loop * 10
+
+                test_run.create_execution(case=case, sortkey=sortkey,
+                                          assignee=form.cleaned_data['default_tester'])
+                loop += 1
+
+            return HttpResponseRedirect(
+                reverse('testruns-get', args=[test_run.pk, ])
+            )
+
+        test_cases = TestCase.objects.filter(pk__in=request.POST.getlist('case'))
+
+        tcs_values = test_cases.select_related('author',
+                                               'case_status',
+                                               'category',
+                                               'priority').order_by('pk')
+        context_data = {
+            'test_cases': tcs_values,
+            'form': form,
+            'disabled_cases': get_disabled_test_cases_count(test_cases)
+        }
+
+        return render(request, self.template_name, context_data)
+
 
 @method_decorator(permission_required('testruns.view_testrun'), name='dispatch')
 class SearchTestRunView(TemplateView):
@@ -185,7 +186,10 @@ def open_run_get_users(case_runs):
     return (dict(testers.iterator()), dict(assignees.iterator()))
 
 
-@method_decorator(permission_required('testruns.view_testrun'), name='dispatch')
+@method_decorator(
+    object_permission_required('testruns.view_testrun', (TestRun, 'pk', 'pk'),
+                               accept_global_perms=True),
+    name='dispatch')
 class GetTestRunView(TemplateView):
     """Display testrun's details"""
 
@@ -264,22 +268,18 @@ def _walk_executions(test_executions):
                                             execution=execution.pk).count())
 
 
-@method_decorator(permission_required('testruns.change_testrun'), name='dispatch')
+@method_decorator(
+    object_permission_required('testruns.change_testrun', (TestRun, 'pk', 'pk'),
+                               accept_global_perms=True),
+    name='dispatch')
 class EditTestRunView(UpdateView):
     model = TestRun
     template_name = 'testruns/mutable.html'
-    form_class = BaseRunForm
-
-    def get_context_data(self, **kwargs):
-        context = super().get_context_data(**kwargs)
-        context['test_plan'] = self.object.plan
-        context['builds'] = Build.objects.filter(product=self.object.plan.product, is_active=True)
-
-        return context
+    form_class = NewRunForm
 
     def get_form(self, form_class=None):
-        form = super().get_form()
-        form.populate(self.object.plan.product_id)
+        form = super().get_form(form_class)
+        form.populate(self.object.plan_id)
 
         return form
 
@@ -373,13 +373,14 @@ class CloneTestRunView(View):
             'manager': test_run.manager,
             'build': test_run.build_id,
             'default_tester': test_run.default_tester,
+            'plan': test_run.plan
         })
-        form.populate(product_id=test_run.plan.product_id)
+
+        form.populate(test_run.plan_id)
 
         context_data = {
             'is_cloning': True,
             'disabled_cases': disabled_cases,
-            'test_plan': test_run.plan,
             'test_cases': test_cases,
             'form': form,
         }
@@ -449,10 +450,10 @@ class AddCasesToRunView(View):
             sort_keys_in_plan = dict((row['case'], row['sortkey']) for row in query_set.iterator())
             for test_case in test_cases:
                 sort_key = sort_keys_in_plan.get(test_case.pk, 0)
-                test_run.add_case_run(case=test_case, sortkey=sort_key)
+                test_run.create_execution(case=test_case, sortkey=sort_key)
         else:
             for test_case in test_cases:
-                test_run.add_case_run(case=test_case)
+                test_run.create_execution(case=test_case)
 
         return HttpResponseRedirect(reverse('testruns-get',
                                             args=[test_run.pk, ]))
@@ -553,3 +554,7 @@ def get_caseruns_of_runs(runs, kwargs=None):
     if status:
         caseruns = caseruns.filter(status__name__iexact=status)
     return caseruns
+
+
+def get_disabled_test_cases_count(test_cases):
+    return test_cases.exclude(case_status=TestCaseStatus.get_confirmed()).count()
